@@ -254,7 +254,8 @@ class ProxyExtensionServer(Server):
             (forms, textareas) = self.__form_extension.get_elements(elements)
             for form in forms:
                 if form["username"].get_name() == userform:
-                    self.__helper.get(self.__form_extension.get_form_uri(form),
+                    uri = self.__form_extension.get_form_uri(form["element"])
+                    self.__helper.get(uri,
                                       userform,
                                       form["password"].get_name(),
                                       self.__form_extension.set_input_forms,
@@ -558,10 +559,6 @@ class ProxyExtensionServer(Server):
         (forms, textareas) = self.__form_extension.get_elements(elements)
         self.__add_event_listeners(forms, textareas, webpage)
         for form in forms:
-            form["element"].add_event_listener(
-                "submit",
-                self.__form_extension.on_form_submit,
-                False)
             self.__form_extension.set_credentials(form, webpage)
 
     def __on_context_menu(self, webpage, context_menu, hit):
