@@ -148,6 +148,7 @@ class SitesManagerChild(Gtk.ListBoxRow):
         self.__window = window
         self.__netloc = netloc
         self.__minimal = None
+        self.__current_child = None
         self.__ephemeral = ephemeral
         self.__views = []
         self.__connected_ids = []
@@ -160,7 +161,7 @@ class SitesManagerChild(Gtk.ListBoxRow):
         builder.add_from_resource("/org/gnome/Eolie/SitesManagerChild.ui")
         builder.connect_signals(self)
         widget = builder.get_object("widget")
-        self.__indicator_label = LabelIndicator()
+        self.__indicator_label = LabelIndicator(True)
         self.__indicator_label.set_property("halign", Gtk.Align.CENTER)
         self.__indicator_label.show()
         self.__separator = builder.get_object("separator")
@@ -196,7 +197,7 @@ class SitesManagerChild(Gtk.ListBoxRow):
             self.update_label()
             self.__indicator_label.update_count(True)
             if view.webview.shown:
-                self.__set_artwork(view.webview)
+                self.__on_webview_favicon_changed(view.webview)
             else:
                 self.__indicator_label.mark_unshown(view.webview)
             if self.__pages_listbox is not None:
@@ -220,10 +221,10 @@ class SitesManagerChild(Gtk.ListBoxRow):
             if self.__pages_listbox is not None:
                 for child in self.__pages_listbox.get_children():
                     if child.view == view:
-                        self.__pages_listbox.remove(child)
+                        child.destroy()
                         break
-        if self.__views:
-            self.__set_artwork(self.__views[0].webview)
+            if self.__views:
+                self.__on_webview_favicon_changed(self.__views[0].webview)
 
     def set_minimal(self, minimal):
         """
@@ -246,6 +247,7 @@ class SitesManagerChild(Gtk.ListBoxRow):
             self.__grid.remove(self.__indicator_label)
             self.__grid.attach(self.__netloc_label, 1, 0, 1, 1)
             self.__pages_listbox = Gtk.ListBox.new()
+            self.__pages_listbox.set_sort_func(self.__sort_func)
             self.__pages_listbox.show()
             self.__separator.show()
             self.__grid.attach(self.__pages_listbox, 0, 2, 2, 1)
@@ -268,8 +270,6 @@ class SitesManagerChild(Gtk.ListBoxRow):
         """
         if netloc != self.__netloc:
             self.__netloc = netloc
-            if self.__views:
-                self.__set_artwork(self.__views[0].webview)
             self.__netloc_label.set_text(self.__netloc)
 
     def update_label(self):
@@ -294,8 +294,11 @@ class SitesManagerChild(Gtk.ListBoxRow):
                 for child in self.__pages_listbox.get_children():
                     if child.view == current:
                         self.__pages_listbox.select_row(child)
+                        self.__current_child = child
+                self.__pages_listbox.invalidate_sort()
             else:
                 self.__pages_listbox.unselect_all()
+                self.__current_child = None
 
     @property
     def empty(self):
@@ -332,18 +335,6 @@ class SitesManagerChild(Gtk.ListBoxRow):
 #######################
 # PROTECTED           #
 #######################
-    def _on_scroll_event(self, eventbox, event):
-        """
-            Switch between children
-            @param eventbox as Gtk.EventBox
-            @param event as Gdk.Event
-        """
-        if event.direction == Gdk.ScrollDirection.UP:
-            self.__window.container.pages_manager.previous()
-        elif event.direction == Gdk.ScrollDirection.DOWN:
-            self.__window.container.pages_manager.next()
-        self.__window.container.ctrl_released()
-
     def _on_button_press_event(self, eventbox, event):
         """
             Hide popover or close view
@@ -385,6 +376,21 @@ class SitesManagerChild(Gtk.ListBoxRow):
 #######################
 # PRIVATE             #
 #######################
+    def __sort_func(self, row1, row2):
+        """
+            Sort pages
+            @param row1 as PageChildRow
+            @param row2 as PageChildRow
+        """
+        # Always show current first
+        if self.__current_child in [row1, row2]:
+            return self.__current_child == row2
+        # Unshown first
+        elif not row2.view.webview.shown and row1.view.webview.shown:
+            return True
+        else:
+            return row2.view.webview.atime > row1.view.webview.atime
+
     def __update_popover_internals(self, widget):
         """
             Little hack to manage Gtk.ModelButton text
@@ -397,37 +403,34 @@ class SitesManagerChild(Gtk.ListBoxRow):
         elif hasattr(widget, "forall"):
             GLib.idle_add(widget.forall, self.__update_popover_internals)
 
-    def __set_artwork(self, webview):
-        """
-            Set initial artwork on widget
-            @param webview as WebView
-        """
-        artwork = App().art.get_icon_theme_artwork(webview.uri,
-                                                   self.__ephemeral)
-        if artwork is not None:
-            self.__image.set_from_icon_name(artwork,
-                                            Gtk.IconSize.INVALID)
-        else:
-            favicon_path = App().art.get_favicon_path(webview.uri)
-            if favicon_path is not None:
-                self.__image.set_from_file(favicon_path)
-            else:
-                self.__image.set_from_icon_name("applications-internet",
-                                                Gtk.IconSize.INVALID)
-
-    def __on_webview_favicon_changed(self, webview, favicon,
-                                     icon_theme_artwork):
+    def __on_webview_favicon_changed(self, webview, surface=None):
         """
             Set favicon
             @param webview as WebView
-            @param favicon as cairo.Surface
-            @param icon_theme_artwork as str
+            @param surface as cairo.Surface
         """
-        if favicon is not None:
-            self.__image.set_from_surface(favicon)
-        elif icon_theme_artwork is not None:
-            self.__image.set_from_icon_name(icon_theme_artwork,
+        if self.get_style_context().has_class("item-selected") and\
+                len(self.__views) > 1 and\
+                webview.view != self.__window.container.current:
+            return
+        if surface is not None:
+            self.__image.set_from_surface(surface)
+            return
+
+        favicon_path = App().art.get_favicon_path(webview.uri)
+        if favicon_path is not None:
+            self.__image.set_from_file(favicon_path)
+            return
+
+        artwork = App().art.get_icon_theme_artwork(webview.uri,
+                                                   webview.ephemeral)
+        if artwork is not None:
+            self.__image.set_from_icon_name(artwork,
                                             Gtk.IconSize.INVALID)
+            return
+
+        self.__image.set_from_icon_name("applications-internet",
+                                        Gtk.IconSize.INVALID)
 
     def __on_query_tooltip(self, widget, x, y, keyboard, tooltip):
         """
@@ -526,7 +529,7 @@ class SitesManagerChild(Gtk.ListBoxRow):
 
     def __on_webview_shown(self, webview):
         """
-            Update indicataor
+            Update indicator
         """
         self.__indicator_label.mark_shown(webview)
-        self.__set_artwork(webview)
+        self.__on_webview_favicon_changed(webview)
