@@ -59,7 +59,7 @@ class WebViewNavigation:
         if App().phishing.is_phishing(uri):
             self._show_phishing_error(uri)
             return
-        self._error = False
+        self.discard_error()
         # If not an URI, start a search
         parsed = urlparse(uri)
         is_uri = parsed.scheme in ["about", "http",
@@ -151,9 +151,9 @@ class WebViewNavigation:
             @param webview as WebView
             @param event as WebKit2.LoadEvent
         """
-        parsed = urlparse(self._uri)
+        parsed = urlparse(self.uri)
         if event == WebKit2.LoadEvent.STARTED:
-            self.emit("uri-changed", self._uri)
+            self.emit("uri-changed", self.uri)
         elif event == WebKit2.LoadEvent.REDIRECTED:
             # Block ads
             if App().settings.get_value("adblock") and\
@@ -161,15 +161,15 @@ class WebViewNavigation:
                     parsed.scheme in ["http", "https"] and\
                     not App().adblock_exceptions.find_parsed(parsed):
                 if App().adblock.is_netloc_blocked(parsed.netloc) or\
-                        App().adblock.is_uri_blocked(self._uri,
+                        App().adblock.is_uri_blocked(self.uri,
                                                      parsed.netloc):
                     Logger.debug("WebView::__wait_for_uri(): blocking %s",
-                                 self._uri)
+                                 self.uri)
                     webview.stop_loading()
                     self._window.container.close_view(self.view)
                     return
         elif event == WebKit2.LoadEvent.COMMITTED:
-            self.emit("uri-changed", self._uri)
+            self.emit("uri-changed", self.uri)
             http_scheme = parsed.scheme in ["http", "https"]
             self.update_zoom_level()
             # Setup eolie internal adblocker
@@ -189,7 +189,7 @@ class WebViewNavigation:
                             self.run_javascript(js, None, None)
                             break
         elif event == WebKit2.LoadEvent.FINISHED:
-            self.update_spell_checking(self._uri)
+            self.update_spell_checking(self.uri)
             self.run_javascript_from_gresource(
                 "/org/gnome/Eolie/Extensions.js", None, None)
             if App().show_tls:
@@ -285,7 +285,7 @@ class WebViewNavigation:
         if not self.is_loading():
             uri = webview.get_property(param.name)
             # JS bookmark (Bookmarklet)
-            if not uri.startswith("javascript:"):
+            if not uri.startswith("javascript:") and not self.error:
                 self.emit("uri-changed", uri)
                 self.set_current_favicon()
 
@@ -323,6 +323,7 @@ class WebViewNavigation:
             parsed = urlparse(uri)
             if mime_type in self.__MIMES:
                 decision.use()
+                return False
             elif parsed.scheme == "file":
                 f = Gio.File.new_for_uri(uri)
                 info = f.query_info("standard::type",
@@ -337,13 +338,16 @@ class WebViewNavigation:
                         Logger.error("""WebViewNavigation::
                                         __on_decide_policy(): %s""", e)
                     decision.ignore()
+                    return True
                 else:
                     decision.use()
+                    return False
             elif self.can_show_mime_type(mime_type):
                 decision.use()
+                return False
             else:
                 decision.download()
-            return False
+                return True
 
         navigation_action = decision.get_navigation_action()
         navigation_uri = navigation_action.get_request().get_uri()
@@ -374,7 +378,7 @@ class WebViewNavigation:
                 decision.ignore()
                 return True
             else:
-                self._error = False
+                self.discard_error()
                 decision.use()
                 return False
         elif mouse_button == 1:
@@ -400,7 +404,7 @@ class WebViewNavigation:
                 return True
             else:
                 self.update_settings_for_uri(navigation_uri)
-                self._error = False
+                self.discard_error()
                 decision.use()
                 return False
         else:
